import { Vec2 } from "../math/Vec2";
export const defaultLayoutNodeState = {
    children: [],
    clientHeight: 0,
    clientWidth: 0,
    clipSize: new Vec2(0, 0),
    clipStart: new Vec2(0, 0),
    hasHorizontalScrollbar: false,
    hasVerticalScrollbar: false,
    scrollHeight: 0,
    scrollWidth: 0,
    scrollX: 0,
    scrollY: 0,
    totalScrollX: 0,
    totalScrollY: 0,
    x: 0,
    y: 0,
};
/**
 * Corresponds to CSS `align-items`. Controls positioning of children on the cross axis.
 */
export var AlignItems;
(function (AlignItems) {
    AlignItems[AlignItems["Center"] = 0] = "Center";
    AlignItems[AlignItems["End"] = 1] = "End";
    AlignItems[AlignItems["Start"] = 2] = "Start";
    /**
     * Stretches the element to fill the parent's cross axis.
     */
    AlignItems[AlignItems["Stretch"] = 3] = "Stretch";
})(AlignItems || (AlignItems = {}));
/**
 *  Corresponds to CSS `justify-content`. Controls positioning of children on the main axis.
 */
export var JustifyContent;
(function (JustifyContent) {
    JustifyContent[JustifyContent["Center"] = 0] = "Center";
    JustifyContent[JustifyContent["End"] = 1] = "End";
    /**
     * Uses equal gaps between all elements and half of that gap before the first element and after
     * the last element.
     */
    JustifyContent[JustifyContent["SpaceAround"] = 2] = "SpaceAround";
    /**
     * Does not leave any gap before the first element or after the last element.
     */
    JustifyContent[JustifyContent["SpaceBetween"] = 3] = "SpaceBetween";
    /**
     * Uses equal gaps between all elements and before the first element and after the last element.
     */
    JustifyContent[JustifyContent["SpaceEvenly"] = 4] = "SpaceEvenly";
    JustifyContent[JustifyContent["Start"] = 5] = "Start";
})(JustifyContent || (JustifyContent = {}));
/**
 * Corresponds to CSS `align-content`, which controls positions and sizes of lines in the flex
 * wrap. Does not have any effect if `FlexWrap` is `NoWrap`.
 */
export var AlignContent;
(function (AlignContent) {
    AlignContent[AlignContent["Center"] = 0] = "Center";
    AlignContent[AlignContent["End"] = 1] = "End";
    /**
     * Uses equal gaps between all elements and half of that gap before the first element and after
     * the last element.
     */
    AlignContent[AlignContent["SpaceAround"] = 2] = "SpaceAround";
    /**
     * Does not leave any gap before the first element or after the last element.
     */
    AlignContent[AlignContent["SpaceBetween"] = 3] = "SpaceBetween";
    /**
     * Uses equal gaps between all elements and before the first element and after the last element.
     */
    AlignContent[AlignContent["SpaceEvenly"] = 4] = "SpaceEvenly";
    AlignContent[AlignContent["Start"] = 5] = "Start";
    AlignContent[AlignContent["Stretch"] = 6] = "Stretch";
})(AlignContent || (AlignContent = {}));
/**
 * Corresponds to CSS `align-self`.
 */
export var AlignSelf;
(function (AlignSelf) {
    /**
     * Does not override the value of parent's `AlignItems`.
     */
    AlignSelf[AlignSelf["Auto"] = 0] = "Auto";
    AlignSelf[AlignSelf["Center"] = 1] = "Center";
    AlignSelf[AlignSelf["End"] = 2] = "End";
    AlignSelf[AlignSelf["Start"] = 3] = "Start";
    /**
     * Stretches the element to fill the parent's cross axis.
     */
    AlignSelf[AlignSelf["Stretch"] = 4] = "Stretch";
})(AlignSelf || (AlignSelf = {}));
/**
 * Corresponds to CSS `flex-direction`.
 */
export var FlexDirection;
(function (FlexDirection) {
    /**
     * Main axis is the vertical one.
     */
    FlexDirection[FlexDirection["Column"] = 0] = "Column";
    /**
     * Reverses the order of elements.
     */
    FlexDirection[FlexDirection["ColumnReverse"] = 1] = "ColumnReverse";
    /**
     * Main axis is the horizontal one.
     */
    FlexDirection[FlexDirection["Row"] = 2] = "Row";
    /**
     * Reverses the order of elements.
     */
    FlexDirection[FlexDirection["RowReverse"] = 3] = "RowReverse";
})(FlexDirection || (FlexDirection = {}));
/**
 * Corresponds to CSS flex-wrap.
 */
export var FlexWrap;
(function (FlexWrap) {
    /**
     * Does not wrap lines, making them potentially overflow the parent.
     */
    FlexWrap[FlexWrap["NoWrap"] = 0] = "NoWrap";
    /**
     * Wraps lines of elements if they exceed available space in the main axis.
     */
    FlexWrap[FlexWrap["Wrap"] = 1] = "Wrap";
    /**
     * Reverses the order of lines.
     */
    FlexWrap[FlexWrap["WrapReverse"] = 2] = "WrapReverse";
})(FlexWrap || (FlexWrap = {}));
/**
 * Determines how the element is clipped. Corresponds to CSS overflow.
 */
export var Overflow;
(function (Overflow) {
    /**
     * Shows scrollbars if needed.
     */
    Overflow[Overflow["Auto"] = 0] = "Auto";
    /**
     * Clips content but doesn't show scrollbars.
     */
    Overflow[Overflow["Hidden"] = 1] = "Hidden";
    /**
     * Shows scrollbars always.
     */
    Overflow[Overflow["Scroll"] = 2] = "Scroll";
    /**
     * Lets content overflow the parent.
     */
    Overflow[Overflow["Visible"] = 3] = "Visible";
})(Overflow || (Overflow = {}));
/**
 * Corresponds to CSS display.
 */
export var Display;
(function (Display) {
    /**
     * Behaves similarly to `flex` in CSS.
     */
    Display[Display["Flex"] = 0] = "Flex";
    /**
     * Hides element from layout and prevents it from participating in layout calculations.
     */
    Display[Display["None"] = 1] = "None";
})(Display || (Display = {}));
/**
 * Corresponds to CSS position.
 */
export var Position;
(function (Position) {
    /**
     * The element will not participate in layout of other elements within the same parent.
     * Coordinates are relative to the parent (since every node is either absolute or relative).
     */
    Position[Position["Absolute"] = 0] = "Absolute";
    /**
     * The name originates from CSS where it means that the offset modifiers (`top`, `left`, etc.)
     * will move the element around but it will not influence the layout of other elements.
     */
    Position[Position["Relative"] = 1] = "Relative";
})(Position || (Position = {}));
/**
 * Corresponds to CSS `text-transform`.
 */
export var TextTransform;
(function (TextTransform) {
    TextTransform[TextTransform["None"] = 0] = "None";
    TextTransform[TextTransform["Capitalize"] = 1] = "Capitalize";
    TextTransform[TextTransform["Lowercase"] = 2] = "Lowercase";
    TextTransform[TextTransform["Uppercase"] = 3] = "Uppercase";
})(TextTransform || (TextTransform = {}));
/**
 * Corresponds to CSS `text-align`.
 */
export var TextAlign;
(function (TextAlign) {
    TextAlign[TextAlign["Center"] = 0] = "Center";
    TextAlign[TextAlign["Left"] = 1] = "Left";
    TextAlign[TextAlign["Right"] = 2] = "Right";
})(TextAlign || (TextAlign = {}));
export var Whitespace;
(function (Whitespace) {
    /**
     * Text will wrap to the next line if it exceeds the width of the parent (if defined).
     */
    Whitespace[Whitespace["Normal"] = 0] = "Normal";
    /**
     * Text will never wrap to the next line.
     */
    Whitespace[Whitespace["NoWrap"] = 1] = "NoWrap";
})(Whitespace || (Whitespace = {}));
const defaultLayoutProps = {
    alignContent: AlignContent.Start,
    alignItems: AlignItems.Start,
    alignSelf: AlignSelf.Auto,
    aspectRatio: undefined,
    borderBottomWidth: 0,
    borderLeftWidth: 0,
    borderRightWidth: 0,
    borderTopWidth: 0,
    borderWidth: 0,
    bottom: undefined,
    columnGap: 0,
    display: Display.Flex,
    flex: 0,
    flexBasis: undefined,
    flexDirection: FlexDirection.Column,
    flexGrow: 0,
    flexShrink: 0,
    flexWrap: FlexWrap.NoWrap,
    gap: 0,
    height: undefined,
    justifyContent: JustifyContent.Start,
    left: undefined,
    marginBottom: 0,
    marginLeft: 0,
    marginRight: 0,
    marginTop: 0,
    maxHeight: undefined,
    maxWidth: undefined,
    minHeight: undefined,
    minWidth: undefined,
    overflowX: Overflow.Visible,
    overflowY: Overflow.Visible,
    paddingBottom: 0,
    paddingLeft: 0,
    paddingRight: 0,
    paddingTop: 0,
    position: Position.Relative,
    right: undefined,
    rowGap: 0,
    top: undefined,
    width: undefined,
    zIndex: undefined,
};
const defaultDecorativeProps = {
    backgroundColor: "transparent",
    borderBottomLeftRadius: 0,
    borderBottomRightRadius: 0,
    borderColor: "transparent",
    borderTopLeftRadius: 0,
    borderTopRightRadius: 0,
    boxShadowColor: "#000",
    boxShadowOffsetX: 0,
    boxShadowOffsetY: 0,
    boxShadowRadius: 0,
    opacity: 1,
};
export const defaultTextStyleProps = {
    color: "#000",
    fontName: "Inter",
    fontSize: 16,
    lineHeight: 20,
    textAlign: TextAlign.Left,
    textTransform: TextTransform.None,
    whitespace: Whitespace.Normal,
};
export function normalizeLayoutProps(input) {
    const result = { ...defaultLayoutProps, ...input };
    result.paddingTop = input.paddingTop ?? input.paddingVertical ?? input.padding ?? 0;
    result.paddingBottom = input.paddingBottom ?? input.paddingVertical ?? input.padding ?? 0;
    result.paddingLeft = input.paddingLeft ?? input.paddingHorizontal ?? input.padding ?? 0;
    result.paddingRight = input.paddingRight ?? input.paddingHorizontal ?? input.padding ?? 0;
    result.marginTop = input.marginTop ?? input.marginVertical ?? input.margin ?? 0;
    result.marginBottom = input.marginBottom ?? input.marginVertical ?? input.margin ?? 0;
    result.marginLeft = input.marginLeft ?? input.marginHorizontal ?? input.margin ?? 0;
    result.marginRight = input.marginRight ?? input.marginHorizontal ?? input.margin ?? 0;
    result.borderBottomWidth = input.borderBottomWidth ?? input.borderWidth ?? 0;
    result.borderTopWidth = input.borderTopWidth ?? input.borderWidth ?? 0;
    result.borderLeftWidth = input.borderLeftWidth ?? input.borderWidth ?? 0;
    result.borderRightWidth = input.borderRightWidth ?? input.borderWidth ?? 0;
    result.columnGap = input.columnGap ?? input.gap ?? 0;
    result.rowGap = input.rowGap ?? input.gap ?? 0;
    result.overflowX = input.overflowX ?? input.overflow ?? Overflow.Visible;
    result.overflowY = input.overflowY ?? input.overflow ?? Overflow.Visible;
    return result;
}
export function normalizeDecorativeProps(input) {
    const result = { ...defaultDecorativeProps, ...input };
    result.borderTopLeftRadius = input.borderTopLeftRadius ?? input.borderRadius ?? 0;
    result.borderTopRightRadius = input.borderTopRightRadius ?? input.borderRadius ?? 0;
    result.borderBottomLeftRadius = input.borderBottomLeftRadius ?? input.borderRadius ?? 0;
    result.borderBottomRightRadius = input.borderBottomRightRadius ?? input.borderRadius ?? 0;
    return result;
}
//# sourceMappingURL=styling.js.map