const EPSILON = 0.001;
/**
 * A 2D vector.
 */
export class Vec2 {
    x;
    y;
    constructor(x, y) {
        this.x = x;
        this.y = y;
    }
    add(other) {
        return new Vec2(this.x + other.x, this.y + other.y);
    }
    subtract(other) {
        return new Vec2(this.x - other.x, this.y - other.y);
    }
    length() {
        return Math.sqrt(this.x * this.x + this.y * this.y);
    }
    normalize() {
        const length = this.length();
        return new Vec2(this.x / length, this.y / length);
    }
    scale(scalar) {
        return new Vec2(this.x * scalar, this.y * scalar);
    }
    cross(other) {
        return this.x * other.y - this.y * other.x;
    }
    dot(other) {
        return this.x * other.x + this.y * other.y;
    }
    distance(other) {
        return this.subtract(other).length();
    }
    lerp(other, t) {
        return this.add(other.subtract(this).scale(t));
    }
    equalsEpsilon(other, epsilon) {
        return Math.abs(this.x - other.x) < epsilon && Math.abs(this.y - other.y) < epsilon;
    }
    equals(other) {
        return this.equalsEpsilon(other, EPSILON);
    }
    data() {
        return [this.x, this.y];
    }
    toString() {
        return `(${this.x}, ${this.y})`;
    }
}
//# sourceMappingURL=Vec2.js.map