const EPSILON = 0.001;
/**
 * A 3-dimensional vector.
 */
export class Vec3 {
    x;
    y;
    z;
    constructor(x, y, z) {
        this.x = x;
        this.y = y;
        this.z = z;
    }
    add(other) {
        return new Vec3(this.x + other.x, this.y + other.y, this.z + other.z);
    }
    subtract(other) {
        return new Vec3(this.x - other.x, this.y - other.y, this.z - other.z);
    }
    length() {
        return Math.sqrt(this.x * this.x + this.y * this.y + this.z * this.z);
    }
    normalize() {
        const length = this.length();
        return new Vec3(this.x / length, this.y / length, this.z / length);
    }
    scale(scalar) {
        return new Vec3(this.x * scalar, this.y * scalar, this.z * scalar);
    }
    cross(other) {
        return new Vec3(this.y * other.z - this.z * other.y, this.z * other.x - this.x * other.z, this.x * other.y - this.y * other.x);
    }
    dot(other) {
        return this.x * other.x + this.y * other.y + this.z * other.z;
    }
    distance(other) {
        return this.subtract(other).length();
    }
    lerp(other, t) {
        return this.add(other.subtract(this).scale(t));
    }
    equalsEpsilon(other, epsilon) {
        return (Math.abs(this.x - other.x) < epsilon &&
            Math.abs(this.y - other.y) < epsilon &&
            Math.abs(this.z - other.z) < epsilon);
    }
    equals(other) {
        return this.equalsEpsilon(other, EPSILON);
    }
    toString() {
        return `(${this.x}, ${this.y}, ${this.z})`;
    }
}
//# sourceMappingURL=Vec3.js.map